@@ -764,12 +764,16 @@ bonobo_activation_init_activation_env (void)
         activation_environment = Bonobo_ActivationEnvironment__alloc ();
 
 	for (i = 0; getenv_values [i].name; i++) {
+		getenv_values [i].value = getenv (getenv_values [i].name);
+
+		if (!getenv_values [i].value)
+			continue;
+
                 Bonobo_ActivationEnvValue value = {
                         (CORBA_char *) getenv_values [i].name,
                         (CORBA_char *) getenv_values [i].value,
                         0 /* flags */ };
-		if (!getenv_values [i].value)
-			continue;
+
                 ORBit_sequence_append (activation_environment, &value);
 	}
 }
@@ -797,7 +801,7 @@ _bonobo_activation_get_activation_env_value (const char *name)
 {
 	int                        i;
 
-	g_return_if_fail (name != NULL);
+	g_return_val_if_fail (name != NULL, NULL);
 
 	for (i = 0; i < activation_environment->_length; i++) {
 		if (strcmp (activation_environment->_buffer [i].name, name) == 0) {
